@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Outc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Outc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -443,6 +443,7 @@ static gboolean
 zip_close_stream (GsfOutput *output)
 {
 	GsfOutfileZip *zip = GSF_OUTFILE_ZIP (output);
+	gboolean result;
 
 	if (!zip->writing)
 		if (!zip_init_write (output))
@@ -460,7 +461,18 @@ zip_close_stream (GsfOutput *output)
 	}
 	zip->root->writing = FALSE;
 
-	return gsf_output_unwrap (G_OBJECT (output), zip->sink);
+	result = gsf_output_unwrap (G_OBJECT (output), zip->sink);
+
+	/* Free unneeded memory */
+	if (zip->stream) {
+		(void) deflateEnd (zip->stream);
+		g_free (zip->stream);
+		zip->stream = NULL;
+		g_free (zip->buf);
+		zip->buf = NULL;
+	}
+
+	return result;
 }
 
 static gboolean
@@ -719,15 +731,15 @@ GSF_CLASS (GsfOutfileZip, gsf_outfile_zip,
 
 /**
  * gsf_outfile_zip_new :
- * @sink :
- * @err   :
+ * @sink: a #GsfOutput to hold the ZIP file
+ * @err: Location to store error, or %NULL; currently unused.
  *
  * Creates the root directory of a Zip file and manages the addition of
  * children.
  *
- * NOTE : adds a reference to @sink
+ * <note>This adds a reference to @sink.</note>
  *
- * Returns : the new zip file handler
+ * Returns: the new zip file handler
  **/
 GsfOutfile *
 gsf_outfile_zip_new (GsfOutput *sink, G_GNUC_UNUSED GError **err)
